@@ -1,14 +1,14 @@
 #' Add 2D kernel density contours.
 #'
 #' Add 2D kernel density contours based on selected sets of observations.
-#' @param pump.subset Character or Numeric: "pooled", "individual", or numeric vector. "pooled" treats all observations as a single set. "individual" is a shortcut for all individual pump neighborhoods. Use of vector of numeric pump IDs to select (subset) from the neighborhoods defined by "pump.select". Negative selection possible. NULL selects all pumps in "pump.select".
-#' @param pump.select Numeric. Vector of numeric pump IDs to define pump neighborhoods (i.e., the "population"). Negative selection possible. NULL selects all pumps.
+#' @param pump.subset Character or Numeric: "pooled", "individual", or numeric vector. "pooled" treats all observations as a single set. "individual" is a shortcut for all individual pump neighborhoods. Use of vector of numeric pump IDs to subset from the neighborhoods defined by \code{pump.select}. Negative selection possible. \code{NULL} selects all pumps in \code{pump.select}.
+#' @param pump.select Numeric. Vector of numeric pump IDs to define pump neighborhoods (i.e., the "population"). Negative selection possible. \code{NULL} selects all pumps.
 #' @param neighborhood.type Character. "voronoi" or "walking"
 #' @param bandwidth Numeric. Bandwidth for kernel density estimation.
 #' @param color Character. Color of contour lines.
 #' @param line.type Character. Line type for contour lines.
-#' @param obs.unit Character. Unit of observation. "unstacked" uses \code{fatalities.unstacked}. "address" uses \code{fatalities.address}. "fatality" uses \code{fatalities}.
-#' @param multi.core Logical or Numeric. TRUE uses parallel::detectCores(). FALSE uses one, single core. You can also specify the number logical cores. On Window, only "multi.core = FALSE" is available.
+#' @param obs.unit Character. Unit of observation: "unstacked" uses \code{fatalities.unstacked}; "address" uses \code{fatalities.address}; "fatality" uses \code{fatalities}.
+#' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. On Windows, only \code{multi.core = FALSE} is available.
 #' @param ... Additional plotting parameters.
 #' @return Add contours to a graphics plot.
 #' @seealso \code{\link{snowMap}},
@@ -22,17 +22,20 @@
 #' @note This function uses KernSmooth::bkde2D().
 #' @export
 #' @examples
-#' # snowMap()
-#' # addKernelDensity()
+#' \dontrun{
 #'
-#' # snowMap()
-#' # addKernelDensity("individual")
+#' snowMap()
+#' addKernelDensity()
 #'
-#' # snowMap()
-#' # addKernelDensity(c(6, 8))
+#' snowMap()
+#' addKernelDensity("individual")
 #'
-#' # snowMap()
-#' # addKernelDensity(pump.select = c(6, 8))
+#' snowMap()
+#' addKernelDensity(c(6, 8))
+#'
+#' snowMap()
+#' addKernelDensity(pump.select = c(6, 8))
+#' }
 
 addKernelDensity <- function(pump.subset = "pooled", pump.select = NULL,
   neighborhood.type = "walking", obs.unit = "unstacked", bandwidth = 0.5,
@@ -40,11 +43,11 @@ addKernelDensity <- function(pump.subset = "pooled", pump.select = NULL,
 
   if (!is.null(obs.unit) & !all(obs.unit %in%
       c("unstacked", "address", "fatality"))) {
-    stop('"obs.unit" must be "unstacked", "address" or "fatality".')
+    stop('obs.unit must be "unstacked", "address" or "fatality".')
   }
 
   if (!all(neighborhood.type %in% c("voronoi", "walking"))) {
-    stop('"neighborhood.type" must either be "voronoi" or "walking".')
+    stop('neighborhood.type must either be "voronoi" or "walking".')
   }
 
   cores <- multiCore(multi.core)
@@ -112,7 +115,7 @@ addKernelDensity <- function(pump.subset = "pooled", pump.select = NULL,
           sel <- names(cases.list) %in% paste0("p", abs(pump.subset)) == FALSE
           cases <- cases.list[sel]
         } else {
-          stop('Use all positive or all negative "pump.subset"!')
+          stop("Use all positive or all negative numbers for pump.subset.")
         }
 
       } else if (neighborhood.type == "voronoi") {
