@@ -1,15 +1,16 @@
 #' Plot Euclidean path pump neighborhoods.
 #'
 #' Plots star graph from pump to its cases.
-#' @param pump.subset Numeric. Vector of numeric pump IDs to select (subset) from the neighborhoods defined by "pump.select". Negative selection possible. NULL selects all pumps in "pump.select".
-#' @param pump.select Numeric. Vector of numeric pump IDs to define pump neighborhoods (i.e., the "population"). Negative selection possible. NULL selects all pumps.
-#' @param vestry Logical. TRUE uses the 14 pumps from the Vestry Report. FALSE uses the 13 in the original map.
+#' @param pump.subset Numeric. Vector of numeric pump IDs to subset from the neighborhoods defined by \code{pump.select}. Negative selection possible. \code{NULL} selects all pumps in \code{pump.select}.
+#' @param pump.select Numeric. Vector of numeric pump IDs to define pump neighborhoods (i.e., the "population"). Negative selection possible. \code{NULL} selects all pumps.
+#' @param vestry Logical. \code{TRUE} uses the 14 pumps from the Vestry Report. \code{FALSE} uses the 13 in the original map.
 #' @param case.set Character. "observed" or "expected".
-#' @param multi.core Logical or Numeric. TRUE uses parallel::detectCores(). FALSE uses one, single core. You can also specify the number logical cores. On Window, only "multi.core = FALSE" is available.
+#' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. On Windows, only \code{multi.core = FALSE} is available.
 #' @return A base R graph.
 #' @export
 #' @examples
 #' \dontrun{
+#'
 #' neighborhoodEuclidean()
 #' neighborhoodEuclidean(-6)
 #' neighborhoodEuclidean(pump.select = 6:7)
@@ -19,7 +20,7 @@ neighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
   vestry = FALSE, case.set = "observed", multi.core = FALSE) {
 
   if (case.set %in% c("observed", "expected") == FALSE) {
-    stop('"case.set" must be "observed" or "expected".')
+    stop('case.set must be "observed" or "expected".')
   }
 
   cores <- multiCore(multi.core)
@@ -30,18 +31,16 @@ neighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
     pump.data <- cholera::pumps
   }
 
+  p.count <- nrow(pump.data)
+  p.ID <- seq_len(p.count)
+
   if (is.null(pump.select)) {
     pump.id <- pump.data$id
     snow.colors <- cholera::snowColors(vestry = TRUE)
   } else {
-    if (vestry) {
-      if (any(abs(pump.select) %in% 1:14) == FALSE) {
-        stop('With "vestry = TRUE", 1 >= |"pump.select"| <= 14')
-      }
-    } else {
-      if (any(abs(pump.select) %in% 1:13 == FALSE)) {
-        stop('With "vestry = FALSE", 1 >= |"pump.select"| <= 13')
-      }
+    if (is.numeric(pump.select) == FALSE) stop("pump.select must be numeric.")
+    if (any(abs(pump.select) %in% p.ID) == FALSE) {
+      stop('With vestry = ', vestry, ', 1 >= |pump.select| <= ', p.count, ".")
     }
 
     if (all(pump.select > 0)) {
@@ -52,7 +51,7 @@ neighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
       pump.id <- pump.data$id[sel]
       snow.colors <- cholera::snowColors(vestry = TRUE)[sel]
     } else {
-      stop('Use all positive or all negative "pump.select"')
+      stop("Use all positive or all negative numbers for pump.select.")
     }
   }
 
@@ -85,7 +84,7 @@ neighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
       nearest.pump.subset <- nearest.pump[unlist(nearest.pump) %in%
         abs(pump.subset) ==- FALSE]
     } else {
-      stop('Use all positive or all negative "pump.subset"!')
+      stop('Use all positive or all negative numbers for "pump.subset"!')
     }
 
     out <- list(pump.data = pump.data,
@@ -103,7 +102,7 @@ neighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
 
 #' Plot method for neighborhoodWalking().
 #'
-#' @param x An object of class "euclidean" created by neighborhoodEuclidean().
+#' @param x An object of class "euclidean" created by \code{neighborhoodEuclidean()}.
 #' @param ... Additional plotting parameters.
 #' @return A base R plot.
 #' @export
@@ -155,7 +154,7 @@ plot.euclidean <- function(x, ...) {
       nearest.pump.subset <- nearest.pump[nearest.pump %in%
         abs(pump.subset) ==- FALSE]
     } else {
-      stop('Use all positive or all negative "pump.subset"!')
+      stop("Use all positive or all negative numbers for pump.subset.")
     }
 
     invisible(lapply(seq_along(anchors.subset), function(i) {
@@ -185,7 +184,7 @@ plot.euclidean <- function(x, ...) {
 
 #' Print method for neighborhoodWalking().
 #'
-#' @param x An object of class "euclidean" created by neighborhoodEuclidean().
+#' @param x An object of class "euclidean" created by \code{neighborhoodEuclidean()}.
 #' @param ... Additional parameters.
 #' @return An R class 'table' vector.
 #' @export
