@@ -1,20 +1,21 @@
 #' Compute the shortest walking path between cases and/or pumps.
 #'
 #' @param origin Numeric or Integer. Numeric ID of case or pump.
-#' @param destination Numeric or Integer. Numeric ID(s) of case(s) or pump(s). Exclusion is possible via negative selection (e.g., -7). Default is NULL: this returns closest pump or "anchor" case.
+#' @param destination Numeric or Integer. Numeric ID(s) of case(s) or pump(s). Exclusion is possible via negative selection (e.g., -7). Default is \code{NULL}: this returns closest pump or "anchor" case.
 #' @param type Character "case-pump", "cases" or "pumps".
 #' @param observed Logical. Use observed or "simulated" expected data.
-#' @param weighted Logical. TRUE computes shortest path in terms of road length. FALSE computes shortest path in terms of nodes.
-#' @param vestry Logical. TRUE uses the 14 pumps from the Vestry Report. FALSE uses the 13 in the original map.
+#' @param weighted Logical. \code{TRUE} computes shortest path in terms of road length. \code{FALSE} computes shortest path in terms of nodes.
+#' @param vestry Logical. \code{TRUE} uses the 14 pumps from the Vestry report. \code{FALSE} uses the 13 in the original map.
 #' @param unit Character. Unit of distance: "meter", "yard" or "native". "native" returns the map's native scale. "unit" is meaningful only when "weighted" is TRUE. See \code{vignette("roads")} for information on unit distances.
 #' @param time.unit Character. "hour", "minute", or "second".
-#' @param walking.speed Numeric. Default walking speed is 5 km/hr.
-#' @note The function uses a case's "address" (i.e., a stack's "anchor" case) to compute distance. Time is computed using distanceTime(). Adam and Eve Court, and Falconberg Court and Falconberg Mews, are disconnected from the larger road network; they form two isolated subgraphs. This has two consequences: first, only cases on Adam and Eve Court can reach pump 2 and those cases cannot reach any other pump; second, cases on Falconberg Court and Mews cannot reach any pump. Unreachable pumps will return distances of "Inf".
+#' @param walking.speed Numeric. Walking speed in km/hr.
+#' @note The function uses a case's "address" (i.e., a stack's "anchor" case) to compute distance. Time is computed using \code{distanceTime()}. Adam and Eve Court, and Falconberg Court and Falconberg Mews, are disconnected from the larger road network; they form two isolated subgraphs. This has two consequences: first, only cases on Adam and Eve Court can reach pump 2 and those cases cannot reach any other pump; second, cases on Falconberg Court and Mews cannot reach any pump. Unreachable pumps will return distances of "Inf".
 #' @return An R list with two elements: a character vector of path nodes and a data frame summary.
 #' @seealso \code{\link{fatalities}}, \code{vignette("pump.neighborhoods")}
 #' @export
 #' @examples
 #' \dontrun{
+#'
 #' # path from case 1 to nearest pump.
 #' walkingPath(1)
 #'
@@ -39,15 +40,15 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
   time.unit = "second", walking.speed = 5) {
 
   if (unit %in% c("meter", "yard", "native") == FALSE) {
-    stop('"unit" must be "meter", "yard" or "native".')
+    stop('unit must be "meter", "yard" or "native".')
   }
 
   if (time.unit %in% c("hour", "minute", "second") == FALSE) {
-    stop('"time.unit" must be "hour", "minute" or "second".')
+    stop('time.unit must be "hour", "minute" or "second".')
   }
 
   if (type %in% c("case-pump", "cases", "pumps") == FALSE) {
-    stop('"type" must be "case-pump", "cases" or "pumps".')
+    stop('type must be "case-pump", "cases" or "pumps".')
   }
 
   if (observed) {
@@ -59,46 +60,33 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
   nodes <- node.data$nodes
   edges <- node.data$edges
   g <- node.data$g
-  n.sim.obs <- nrow(cholera::regular.cases)
+
+  obs.ct <- nrow(cholera::fatalities)
+  exp.ct <- nrow(cholera::regular.cases)
+
+  if (observed) ct <- obs.ct else ct <- exp.ct
+
+  if (vestry) {
+    p.data <- cholera::pumps.vestry
+  } else {
+    p.data <- cholera::pumps
+  }
+
+  p.count <- nrow(p.data)
+  p.ID <- seq_len(p.count)
+
+  # ----- #
 
   if (type == "case-pump") {
-    if (observed) {
-      if (origin %in% 1:578 == FALSE) {
-        txt1 <- 'With type = "case-pump" and "observed" = TRUE,'
-        txt2 <- '"origin" must be between 1 and 578.'
-        stop(paste(txt1, txt2))
-      }
-    } else {
-      if (origin %in% 1:n.sim.obs == FALSE) {
-        txt1 <- 'With type = "case-pump" and "observed" = FALSE,'
-        txt2 <- paste('"origin" must be between 1 and', paste0(n.sim.obs, "."))
-        stop(paste(txt1, txt2))
-      }
+    if (origin %in% seq_len(ct) == FALSE) {
+      txt1 <- 'With type = "case-pump" and observed = '
+      txt2 <- 'origin must be between 1 and '
+      stop(txt1, observed, ", ", txt2, ct, ".")
     }
 
-    if (!is.null(destination)) {
-      if (vestry) {
-        if (any(abs(destination) %in% 1:14 == FALSE)) {
-          txt1 <- 'With type = "case-pump" and "vestry = TRUE",'
-          txt2 <- '1 >= |destination| <= 14.'
-          stop(paste(txt1, txt2))
-        } else {
-          pumps <- cholera::pumps.vestry[destination, ]
-        }
-      } else {
-        if (any(abs(destination) %in% 1:13 == FALSE)) {
-          txt1 <- 'With type = "case-pump" and "vestry = FALSE",'
-          txt2 <- '1 >= |destination| <= 13.'
-          stop(paste(txt1, txt2))
-        } else {
-          pumps <- cholera::pumps[destination, ]
-        }
-      }
-    } else {
-      if (vestry) {
-        pumps <- cholera::pumps.vestry
-      } else {
-        pumps <- cholera::pumps
+    if (is.null(destination) == FALSE) {
+      if (any(abs(destination) %in% p.ID == FALSE)) {
+        stop('With vestry = ', vestry, ', 1 >= |destination| <= ', p.count, ".")
       }
     }
 
@@ -140,8 +128,9 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
       alter.node <- NA
     } else {
       sel <- which.min(d)
-      alter.id <- nodes[nodes$node %in% names(sel), "pump"]
-      p.name <- pumps[pumps$id == alter.id, "street"]
+      node.sel <- nodes$node %in% names(sel) & nodes$pump != 0
+      alter.id <- nodes[node.sel, "pump"]
+      p.name <- p.data[p.data$id == alter.id, "street"]
       alter.node <- names(sel)
     }
 
@@ -163,19 +152,11 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
                                   row.names = NULL))
 
   } else if (type == "cases") {
-    if (observed) {
-      if (any(abs(c(origin, destination)) %in% 1:578 == FALSE)) {
-        txt1 <- 'With type = "cases", the absolute value of both "origin"'
-        txt2 <- 'and "destination" must be a whole number between 1 and 578.'
-        stop(paste(txt1, txt2))
-      }
-    } else {
-      if (any(abs(c(origin, destination)) %in% 1:n.sim.obs == FALSE)) {
-        txt1 <- 'With type = "case-pump" and "observed" = FALSE,'
-        txt2 <- 'both "origin" and "destination" must be whole numbers between'
-        txt3 <- paste('1 and', paste0(n.sim.obs, "."))
-        stop(paste(txt1, txt2, txt3))
-      }
+    if (any(abs(c(origin, destination)) %in% seq_len(ct) == FALSE)) {
+      txt1 <- 'With type = "cases" and observed = '
+      txt2 <- ', the absolute value of origin and destination must be '
+      txt3 <- 'between 1 and '
+      stop(txt1, observed, txt2, txt3, ct, ".")
     }
 
     if (observed) {
@@ -225,7 +206,8 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
       alter.node <- NA
     } else {
       sel <- which.min(d)
-      alter.id <- nodes[nodes$node %in% names(sel), "anchor"]
+      node.sel <- nodes$node %in% names(sel) & nodes$anchor != 0
+      alter.id <- nodes[node.sel, "anchor"]
       alter.node <- names(sel)
     }
 
@@ -258,22 +240,10 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
     }
 
   } else if (type == "pumps") {
-    if (vestry) {
-      pumps <- cholera::pumps.vestry
-
-      if (any(abs(c(origin, destination)) %in% 1:14 == FALSE)) {
-        txt1 <- 'With type = "pumps" and "vestry = TRUE",'
-        txt2 <- 'origin and destination must whole numbers 1 >= |x| <= 14.'
-        stop(paste(txt1, txt2))
-      }
-    } else {
-      pumps <- cholera::pumps
-
-      if (any(abs(c(origin, destination)) %in% 1:13 == FALSE)) {
-        txt1 <- 'With type = "pumps" and "vestry = FALSE",'
-        txt2 <- 'origin and destination must be whole numbers 1 >= |x| <= 13.'
-        stop(paste(txt1, txt2))
-      }
+    if (any(abs(c(origin, destination)) %in% p.ID == FALSE)) {
+      txt1 <- 'With type = "pumps" and vestry = '
+      txt2 <- ', origin and destination must whole numbers 1 >= |x| <= '
+      stop(txt1, vestry, txt2, p.count, ".")
     }
 
     ego.node <- nodes[nodes$pump == origin, "node"]
@@ -315,17 +285,17 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
 
     if (weighted) {
       path <- names(unlist(igraph::shortest_paths(g, ego.node, alter.node,
-                                                  weights = edges$d)$vpath))
+        weights = edges$d)$vpath))
     } else {
       path <- names(unlist(igraph::shortest_paths(g, ego.node,
-                                                  alter.node)$vpath))
+        alter.node)$vpath))
     }
 
     out <- list(path = path,
                 data = data.frame(pumpA = A,
-                                  nameA = pumps[pumps$id == A, "street"],
+                                  nameA = p.data[p.data$id == A, "street"],
                                   pumpB = B,
-                                  nameB = pumps[pumps$id == B, "street"],
+                                  nameB = p.data[p.data$id == B, "street"],
                                   distance = d[sel],
                                   stringsAsFactors = FALSE,
                                   row.names = NULL))
@@ -375,7 +345,7 @@ walkingPath <- function(origin, destination = NULL, type = "case-pump",
 
 print.walking_path <- function(x, ...) {
   if (class(x) != "walking_path") {
-    stop('"x"\'s class needs to be "walking_path".')
+    stop('"x"\'s class must be "walking_path".')
   }
 
   print(x[c("path", "data")])
@@ -387,7 +357,7 @@ print.walking_path <- function(x, ...) {
 #' @param zoom Logical.
 #' @param radius Numeric. Control the degree of zoom.
 #' @param unit.posts Character. "distance" for mileposts; "time" for timeposts; NULL for no posts.
-#' @param unit.interval Numeric. Set interval between posts. When "unit.posts" is "distance", "unit.interval" automatically defaults to 50 meters. When "unit.posts" is "time", "unit.interval" automatically defaults to 60 seconds.
+#' @param unit.interval Numeric. Set interval between posts. When \code{unit.posts = "distance"}, \code{unit.interval} defaults to 50 meters. When \code{unit.posts = "time"}, \code{unit.interval} defaults to 60 seconds.
 #' @param alpha.level Numeric. Alpha level transparency for path: a value in [0, 1].
 #' @param ... Additional plotting parameters.
 #' @return A base R plot.
@@ -401,17 +371,17 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
   unit.posts = "distance", unit.interval = NULL, alpha.level = 1, ...) {
 
   if (class(x) != "walking_path") {
-    stop('"x"\'s class needs to be "walking_path".')
+    stop('x\'s class must be "walking_path".')
   }
 
   if (is.na(x$alter.node)) {
     txt1 <- paste("Case", x$origin, "is part of an isolated subgraph.")
-    txt2 <- "It (technically) has no neareast pump."
-    stop(paste(txt1, txt2))
+    txt2 <- "It (technically) has no nearest pump."
+    stop(txt1, txt2)
   }
 
-  if (isFALSE(alpha.level > 0 | alpha.level <= 1)) {
-    stop('"alpha.level" must be > 0 and <= 1')
+  if ((alpha.level > 0 & alpha.level <= 1) == FALSE) {
+    stop('alpha.level must be > 0 and <= 1.')
   }
 
   rd <- cholera::roads[cholera::roads$street %in% cholera::border == FALSE, ]
@@ -429,7 +399,7 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
   dat <- numericNodeCoordinates(x$path)
 
   if (x$type == "case-pump") {
-    alter <- nodes[nodes$node == alter.node, "pump"]
+    alter <- nodes[nodes$node == alter.node & nodes$pump != 0, "pump"]
 
     if (alpha.level != 1) {
       case.color <- grDevices::adjustcolor(colors[alter], alpha.f = alpha.level)
@@ -445,7 +415,7 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
     }
 
   } else if (x$type == "cases") {
-    alter <- nodes[nodes$node == alter.node, "anchor"]
+    alter <- nodes[nodes$node == alter.node & nodes$anchor != 0, "anchor"]
     case.color <- "blue"
 
     if (x$observed) {
@@ -460,7 +430,7 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
         destination.obs <- cholera::fatalities[cholera::fatalities$case ==
           alter, c("x", "y")]
       } else {
-        destination.obs <-  cholera::regular.cases[alter, ]
+        destination.obs <- cholera::regular.cases[alter, ]
       }
     } else {
       id <- x$destination[x$sel]
@@ -481,7 +451,7 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
       origin.obs <- cholera::pumps[cholera::pumps$id == x$origin, c("x", "y")]
     }
 
-    alter <- nodes[nodes$node == alter.node, "pump"]
+    alter <- nodes[nodes$node == alter.node & nodes$anchor != 0, "anchor"]
     case.color <- "blue"
   }
 
@@ -569,7 +539,7 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
 
   if (is.null(unit.posts) == FALSE) {
     if (unit.posts %in% c("distance", "time") == FALSE) {
-      stop('If specified, "unit.posts" must be "distance" or "time".')
+      stop('If specified, unit.posts must be "distance" or "time".')
     } else {
       if (is.null(unit.interval)) {
         if (unit.posts == "distance")  {
@@ -579,7 +549,7 @@ plot.walking_path <- function(x, zoom = TRUE, radius = 0.5,
         }
       } else {
         if (!is.numeric(unit.interval)) {
-          stop('"unit.interval" must be numeric.')
+          stop('unit.interval must be numeric.')
         }
       }
 
